@@ -112,19 +112,6 @@ class DBManager:
 
     def __init__(self, connection):
         self.con = connection
-        self.BIDPEROFFER_D = InputsByIntervalDateTime(
-            table_name='BIDPEROFFER_D', table_columns=['INTERVAL_DATETIME', 'DUID', 'BIDTYPE', 'BANDAVAIL1',
-                                                       'BANDAVAIL2', 'BANDAVAIL3', 'BANDAVAIL4', 'BANDAVAIL5',
-                                                       'BANDAVAIL6', 'BANDAVAIL7', 'BANDAVAIL8', 'BANDAVAIL9',
-                                                       'BANDAVAIL10', 'MAXAVAIL', 'ENABLEMENTMIN', 'ENABLEMENTMAX',
-                                                       'LOWBREAKPOINT', 'HIGHBREAKPOINT'],
-            table_primary_keys=['INTERVAL_DATETIME', 'DUID', 'BIDTYPE'], con=self.con)
-        self.BIDDAYOFFER_D = InputsByDay(
-            table_name='BIDDAYOFFER_D', table_columns=['SETTLEMENTDATE', 'DUID', 'BIDTYPE', 'PRICEBAND1', 'PRICEBAND2',
-                                                       'PRICEBAND3', 'PRICEBAND4', 'PRICEBAND5', 'PRICEBAND6',
-                                                       'PRICEBAND7', 'PRICEBAND8', 'PRICEBAND9', 'PRICEBAND10', 'T1',
-                                                       'T2', 'T3', 'T4', 'MINIMUMLOAD'],
-            table_primary_keys=['SETTLEMENTDATE', 'DUID', 'BIDTYPE'], con=self.con)
         self.DISPATCHREGIONSUM = InputsBySettlementDate(
             table_name='DISPATCHREGIONSUM', table_columns=['SETTLEMENTDATE', 'REGIONID', 'TOTALDEMAND',
                                                            'DEMANDFORECAST', 'INITIALSUPPLY'],
@@ -283,8 +270,6 @@ class DBManager:
                 self.DISPATCHINTERCONNECTORRES.add_data(year=year, month=month)
                 self.DISPATCHREGIONSUM.add_data(year=year, month=month)
                 self.DISPATCHLOAD.add_data(year=year, month=month)
-                self.BIDPEROFFER_D.add_data(year=year, month=month)
-                self.BIDDAYOFFER_D.add_data(year=year, month=month)
                 self.DISPATCHCONSTRAINT.add_data(year=year, month=month)
                 self.DISPATCHPRICE.add_data(year=year, month=month)
 
@@ -686,6 +671,7 @@ class _MultiDataSource(_MMSTable):
         if 'INTERVENTION' in data.columns:
             data = data[data['INTERVENTION'] == 0]
         data = data.loc[:, self.table_columns]
+        data = data.drop_duplicates(subset=self.table_primary_keys)
         with self.con:
             data.to_sql(self.table_name, con=self.con, if_exists='append', index=False)
             self.con.commit()
@@ -824,7 +810,7 @@ class InputsBySettlementDate(_MultiDataSource):
         ...   'SETTLEMENTDATE': ['2019/01/01 11:55:00', '2019/01/01 12:00:00'],
         ...   'INITIALMW': [1.0, 2.0]})
 
-        >>> data.to_sql('EXAMPLE', con=con, if_exists='append', index=False)
+        >>> _ = data.to_sql('EXAMPLE', con=con, if_exists='append', index=False)
 
         When we call get_data the output is filtered by SETTLEMENTDATE.
 
@@ -887,7 +873,7 @@ class InputsByIntervalDateTime(_MultiDataSource):
         ...   'INTERVAL_DATETIME': ['2019/01/01 11:55:00', '2019/01/01 12:00:00'],
         ...   'INITIALMW': [1.0, 2.0]})
 
-        >>> data.to_sql('EXAMPLE', con=con, if_exists='append', index=False)
+        >>> _ = data.to_sql('EXAMPLE', con=con, if_exists='append', index=False)
 
         When we call get_data the output is filtered by INTERVAL_DATETIME.
 
@@ -955,7 +941,7 @@ class InputsByDay(_MultiDataSource):
         ...   'SETTLEMENTDATE': ['2019/01/01 00:00:00', '2019/01/02 00:00:00'],
         ...   'INITIALMW': [1.0, 2.0]})
 
-        >>> data.to_sql('EXAMPLE', con=con, if_exists='append', index=False)
+        >>> _ = data.to_sql('EXAMPLE', con=con, if_exists='append', index=False)
 
         When we call get_data the output is filtered by SETTLEMENTDATE and the results from the appropriate market
         day starting at 04:05:00 are retrieved. In the results below note when the output changes
@@ -1045,7 +1031,7 @@ class InputsStartAndEnd(_SingleDataSource):
         ...   'END_DATE': ['2019/01/02 00:00:00', '2019/01/03 00:00:00'],
         ...   'INITIALMW': [1.0, 2.0]})
 
-        >>> data.to_sql('EXAMPLE', con=con, if_exists='append', index=False)
+        >>> _ = data.to_sql('EXAMPLE', con=con, if_exists='append', index=False)
 
         When we call get_data the output is filtered by START_DATE and END_DATE.
 
@@ -1127,7 +1113,7 @@ class InputsByMatchDispatchConstraints(_AllHistDataSource):
         ...   'VERSIONNO': [1, 2, 2, 3],
         ...   'RHS': [1.0, 2.0, 2.0, 3.0]})
 
-        >>> data.to_sql('EXAMPLE', con=con, if_exists='append', index=False)
+        >>> _ = data.to_sql('EXAMPLE', con=con, if_exists='append', index=False)
 
         >>> data = pd.DataFrame({
         ...   'SETTLEMENTDATE' : ['2019/01/02 00:00:00', '2019/01/02 00:00:00', '2019/01/03 00:00:00',
@@ -1137,7 +1123,7 @@ class InputsByMatchDispatchConstraints(_AllHistDataSource):
         ...                              '2019/01/03 00:00:00'],
         ...   'GENCONID_VERSIONNO': [1, 2, 2, 3]})
 
-        >>> data.to_sql('DISPATCHCONSTRAINT', con=con, if_exists='append', index=False)
+        >>> _ = data.to_sql('DISPATCHCONSTRAINT', con=con, if_exists='append', index=False)
 
         When we call get_data the output is filtered by the contents of DISPATCHCONSTRAINT.
 
@@ -1219,7 +1205,7 @@ class InputsByEffectiveDateVersionNoAndDispatchInterconnector(_SingleDataSource)
         ...   'VERSIONNO': [1, 2, 2, 3],
         ...   'INITIALMW': [1.0, 2.0, 2.0, 3.0]})
 
-        >>> data.to_sql('EXAMPLE', con=con, if_exists='append', index=False)
+        >>> _ = data.to_sql('EXAMPLE', con=con, if_exists='append', index=False)
 
         We also need to add data to DISPATCHINTERCONNECTORRES because the results of the get_data method are filtered
         against this table
@@ -1228,7 +1214,7 @@ class InputsByEffectiveDateVersionNoAndDispatchInterconnector(_SingleDataSource)
         ...   'INTERCONNECTORID': ['X', 'X', 'Y'],
         ...   'SETTLEMENTDATE': ['2019/01/02 00:00:00', '2019/01/03 00:00:00', '2019/01/02 00:00:00']})
 
-        >>> data.to_sql('DISPATCHINTERCONNECTORRES', con=con, if_exists='append', index=False)
+        >>> _ = data.to_sql('DISPATCHINTERCONNECTORRES', con=con, if_exists='append', index=False)
 
         When we call get_data the output is filtered by the contents of DISPATCHCONSTRAINT.
 
@@ -1344,7 +1330,7 @@ class InputsByEffectiveDateVersionNo(_SingleDataSource):
         ...   'VERSIONNO': [1, 2, 2, 3],
         ...   'INITIALMW': [1.0, 2.0, 2.0, 3.0]})
 
-        >>> data.to_sql('EXAMPLE', con=con, if_exists='append', index=False)
+        >>> _ = data.to_sql('EXAMPLE', con=con, if_exists='append', index=False)
 
         When we call get_data the output is filtered by most recent effective date and highest version no.
 
@@ -1449,7 +1435,8 @@ class InputsNoFilter(_SingleDataSource):
         ...   'DUID': ['X', 'Y'],
         ...   'INITIALMW': [1.0, 2.0]})
 
-        >>> data.to_sql('EXAMPLE', con=con, if_exists='append', index=False)
+        >>> _ = data.to_sql('EXAMPLE', con=con, if_exists='append', index=False)
+
 
         When we call get_data all data in the table is returned.
 
